SimpleTokenContractCalls

Enum SimpleTokenContractCalls 

pub enum SimpleTokenContractCalls {
    balanceOf(balanceOfCall),
    balances(balancesCall),
    totalSupply(totalSupplyCall),
    transfer(transferCall),
}
Container for all the SimpleTokenContract function calls.

Variants



balanceOf(balanceOfCall)



balances(balancesCall)



totalSupply(totalSupplyCall)



transfer(transferCall)

Implementations

Source

impl SimpleTokenContractCalls

pub const SELECTORS: &'static [[u8; 4]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.